/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.core;

import java.io.File;
import java.io.IOException;

import org.xml.sax.SAXException;

import benten.core.Files;
import benten.core.HelpTransUnitId;
import benten.core.Xliff;
import benten.core.XliffFileFilter;
import benten.twa.filter.core.valueobject.BentenConvertToXliffProcessInput;
import benten.twa.filter.model.HtmlInlineTextBuilder;
import benten.twa.filter.model.SentenceSplittedList;
import benten.twa.filter.model.HtmlInlineTextBuilder.InlineText;
import blanco.xliff.BlancoXliffUtil;
import blanco.xliff.valueobject.BlancoXliffBody;
import blanco.xliff.valueobject.BlancoXliffFile;
import blanco.xliff.valueobject.BlancoXliffHeader;
import blanco.xliff.valueobject.BlancoXliffTool;
import blanco.xliff.valueobject.BlancoXliffTransUnit;

public class BentenConvertToXliffProcessImpl implements BentenConvertToXliffProcess {

	public int execute(final BentenConvertToXliffProcessInput input) throws IOException, IllegalArgumentException {
		explore(input, new File(input.getSourcedir()));

		return 0;
	}

	protected void explore(final BentenConvertToXliffProcessInput input, final File targetDir) {
		final File[] files = targetDir.listFiles();
		for (File file : files) {
			if (file.isFile() == false) {
				continue;
			}
			if (file.getName().endsWith(".html") == false && file.getName().endsWith(".htm") == false) {
				continue;
			}

			try {
				processFile(input, file);
			} catch (IOException e) {
				// 例外発生。
				e.printStackTrace();
			} catch (SAXException e) {
				// 例外発生。
				e.printStackTrace();
			}
		}
	}

	public static void processFile(final BentenConvertToXliffProcessInput input, final File htmlFile)
			throws IOException, SAXException {
		File destFile = new File(input.getTargetdir(), Files.relativePath(new File(input.getSourcedir()), htmlFile));
		File destDir = destFile.getParentFile();

		destDir.mkdirs();
		String baseName = Files.baseName(htmlFile);
		File outFile = XliffFileFilter.appendExtension(new File(destDir, baseName));

		Xliff xliff = Xliff.newInstance(outFile);
		BlancoXliffFile xliffFile = xliff.createBlancoXliffFile();
		xliffFile.setSourceLanguage("en-US");
		xliffFile.setTargetLanguage("ja-JP");
		xliffFile.setDatatype("helphtml");

		BlancoXliffHeader header = xliffFile.getHeader();
		BlancoXliffBody body = xliffFile.getBody();

		BlancoXliffTool tool = new BlancoXliffTool();
		tool.setToolId("help");
		tool.setToolName("Eclipse - Help");
		BlancoXliffUtil.setTool(header, tool);

		String path = Files.relativePath(new File(input.getSourcedir()).getParentFile(), htmlFile).replace('\\', '/')
				.substring(1);
		int id = 1;

		for (InlineText inline : new HtmlInlineTextBuilder(htmlFile)) {
			String text = inline.getText();
			SentenceSplittedList splittedList = new SentenceSplittedList(text);
			if (splittedList.size() > 1) {
				for (int subId = 0; subId < splittedList.size(); subId++) {
					HelpTransUnitId helpId = new HelpTransUnitId(path, id, subId + 1, splittedList.size());
					createTransUnit(body, helpId, splittedList.get(subId));
				}
			} else {
				HelpTransUnitId helpId = new HelpTransUnitId(path, id);
				createTransUnit(body, helpId, text);
			}
			id++;
		}
		xliff.save();
	}

	protected static void createTransUnit(BlancoXliffBody body, HelpTransUnitId helpId, String source) {
		BlancoXliffTransUnit unit = new BlancoXliffTransUnit();
		unit.setId(helpId.toString());
		unit.setSource(source);
		body.getTransUnitList().add(unit);
	}
}
