/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.core;

import java.io.File;
import java.io.IOException;
import java.util.Iterator;

import org.xml.sax.SAXException;

import benten.core.Files;
import benten.core.HelpTransUnitId;
import benten.core.HtmlFileFilter;
import benten.core.Xliff;
import benten.twa.filter.core.valueobject.BentenExportHtmlProcessInput;
import benten.twa.filter.model.HtmlInlineTextBuilder;
import benten.twa.filter.model.HtmlInlineTextBuilder.InlineText;
import blanco.xliff.valueobject.BlancoXliffTarget;
import blanco.xliff.valueobject.BlancoXliffTransUnit;

public class BentenExportHtmlProcessImpl implements BentenExportHtmlProcess {

	public int execute(final BentenExportHtmlProcessInput input) throws IOException, IllegalArgumentException {
		explore(input, new File(input.getSourcexliffdir()));

		return 0;
	}

	protected void explore(final BentenExportHtmlProcessInput input, final File targetDir) {
		final File[] files = targetDir.listFiles();
		for (File file : files) {
			if (file.isFile() == false) {
				continue;
			}
			if (file.getName().endsWith(".xlf") == false) {
				continue;
			}

			try {
				processFile(input, file);
			} catch (IOException e) {
				// 例外発生。
				e.printStackTrace();
			} catch (SAXException e) {
				// 例外発生。
				e.printStackTrace();
			}
		}
	}

	public static void processFile(final BentenExportHtmlProcessInput input, File xliffFile) throws IOException,
			SAXException {
		String relativePath = Files.relativePath(new File(input.getSourcexliffdir()), xliffFile);
		File toDir = new File(input.getTargetdir(), relativePath).getParentFile();
		File htmlDir = new File(input.getSourcehtmldir(), relativePath).getParentFile();
		writeHtmlFromXliff(xliffFile, htmlDir, toDir);
	}

	protected static void writeHtmlFromXliff(File xliffFile, File htmlDir, File toDir) throws IOException, SAXException {
		Xliff xliff = Xliff.loadInstance(xliffFile);
		Iterator<BlancoXliffTransUnit> units = xliff.getAllTransUnitList().iterator();
		String baseName = Files.baseName(xliffFile);
		File inHtmlFile = HtmlFileFilter.appendExtension(new File(htmlDir, baseName));
		HtmlInlineTextBuilder htmlBuilder = new HtmlInlineTextBuilder(inHtmlFile);

		for (InlineText inline : htmlBuilder) {
			StringBuilder target = new StringBuilder();

			while (units.hasNext()) {
				BlancoXliffTransUnit unit = units.next();
				BlancoXliffTarget t = unit.getTarget();
				if (t != null) {
					target.append(t.getTarget());
				}
				if (!HelpTransUnitId.hasContinue(unit.getId())) {
					break;
				}
			}
			if (target.length() > 0) {
				inline.setText(target.toString());
			} else {
				inline.setText(inline.getText());
			}
		}

		toDir.mkdirs();
		File outHtmlFile = HtmlFileFilter.appendExtension(new File(toDir, baseName));
		htmlBuilder.writeTo(outHtmlFile);
	}
}
