/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.core;

import java.io.File;
import java.io.IOException;

import benten.core.Files;
import benten.twa.filter.core.valueobject.BentenImportHtmlProcessInput;
import blanco.html.normalizer.util.BlancoHtmlNormalizerUtil;

public class BentenImportHtmlProcessImpl implements BentenImportHtmlProcess {

	public int execute(final BentenImportHtmlProcessInput input) throws IOException, IllegalArgumentException {
		explore(input, new File(input.getSourcedir()));

		return 0;
	}

	protected void explore(final BentenImportHtmlProcessInput input, final File targetDir) {
		final File[] files = targetDir.listFiles();
		for (File file : files) {
			if (file.isFile() == false) {
				continue;
			}
			if (file.getName().endsWith(".html") == false && file.getName().endsWith(".htm") == false) {
				continue;
			}

			try {
				processFile(input, file);
			} catch (IOException e) {
				// 例外発生。
				e.printStackTrace();
			}
		}
	}

	public static void processFile(final BentenImportHtmlProcessInput input, File htmlFile) throws IOException {
		byte[] bytes = Files.readFileToByteArray(htmlFile);
		if (input.getNormalizehtml()) {
			bytes = BlancoHtmlNormalizerUtil.normalize(bytes);
		}
		File outputHtmlFile = new File(input.getTargetdir(), Files.relativePath(new File(input.getSourcedir()),
				htmlFile));
		outputHtmlFile.getParentFile().mkdirs();
		Files.writeByteArrayToFile(outputHtmlFile, bytes);
	}
}
