/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.dialogs;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;

import benten.twa.filter.handler.ConvertToXliffHandler.ConvertToXliffStatus;
import benten.twa.ui.AbstractWorkflowDialog;
import benten.twa.ui.DirectoryTextField;
import benten.ui.UiStatus;
import benten.ui.UiStatusException;

/**
 * HTML－XLIFF 変換ダイアログです。
 */
public class ConvertToXliffDialog extends AbstractWorkflowDialog {

	private final ConvertToXliffControls controls = new ConvertToXliffControls();

	public static class ConvertToXliffControls {
		public DirectoryTextField fromDirText;
		public DirectoryTextField toDirText;
	}

	public ConvertToXliffDialog(Shell parentShell, IStructuredSelection selection) {
		super(parentShell, selection, "HTML を XLIFF に変換");
	}

	@Override
	public void createControls(Composite composite) {
		composite.setLayout(new GridLayout(3, false));

		controls.fromDirText = new DirectoryTextField(composite, "変換元");
		controls.fromDirText.addModifyListener(this);
		controls.fromDirText.setText(getStructuredSelectionString());

		controls.toDirText = new DirectoryTextField(composite, "変換先");
		controls.toDirText.addModifyListener(this);

		copyParent(controls.fromDirText, controls.toDirText);
	}

	@Override
	public IStatus getResultStatus() {
		ConvertToXliffStatus status = new ConvertToXliffStatus();
		status.fromDir = controls.fromDirText.getFile();
		status.toDir = controls.toDirText.getFile();
		return status;
	}

	@Override
	public IStatus validate() throws UiStatusException {
		validatePath(controls.fromDirText);
		validatePath(controls.toDirText);
		validateFromTo(controls.fromDirText, controls.toDirText);
		return UiStatus.OK_STATUS;
	}
}
