/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.dialogs;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;

import benten.twa.filter.handler.ExportHtmlHandler.ExportHtmlStatus;
import benten.twa.ui.AbstractWorkflowDialog;
import benten.twa.ui.DirectoryTextField;
import benten.ui.UiStatus;
import benten.ui.UiStatusException;

/**
 * HTML エクスポート・ダイアログです。
 */
public class ExportHtmlDialog extends AbstractWorkflowDialog {

	private final ExportHtmlControls controls = new ExportHtmlControls();

	public static class ExportHtmlControls {
		public DirectoryTextField fromXliffDirText;
		public DirectoryTextField fromHtmlDirText;
		public DirectoryTextField toDirText;
	}

	public ExportHtmlDialog(Shell parentShell, IStructuredSelection selection) {
		super(parentShell, selection, "HTML のエクスポート");
	}

	@Override
	public void createControls(Composite composite) {
		composite.setLayout(new GridLayout(3, false));

		controls.fromXliffDirText = new DirectoryTextField(composite, "XLIFF");
		controls.fromXliffDirText.addModifyListener(this);
		controls.fromXliffDirText.setText(getStructuredSelectionString());

		controls.fromHtmlDirText = new DirectoryTextField(composite, "HTML");
		controls.fromHtmlDirText.addModifyListener(this);

		controls.toDirText = new DirectoryTextField(composite, "エクスポート先");
		controls.toDirText.addModifyListener(this);

		copyParent(controls.fromXliffDirText, controls.fromHtmlDirText);
		copyParent(controls.fromXliffDirText, controls.toDirText);
	}

	@Override
	public IStatus getResultStatus() {
		ExportHtmlStatus status = new ExportHtmlStatus();
		status.fromXliffDir = controls.fromXliffDirText.getFile();
		status.fromHtmlDir = controls.fromHtmlDirText.getFile();
		status.toDir = controls.toDirText.getFile();
		return status;
	}

	@Override
	public IStatus validate() throws UiStatusException {
		validatePath(controls.fromXliffDirText);
		validatePath(controls.fromHtmlDirText);
		validatePath(controls.toDirText);
		validateFromTo(controls.fromXliffDirText, controls.fromHtmlDirText);
		validateFromTo(controls.fromXliffDirText, controls.toDirText);
		validateFromTo(controls.fromHtmlDirText, controls.toDirText);
		return UiStatus.OK_STATUS;
	}
}
