/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.dialogs;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;

import benten.twa.filter.handler.ImportHtmlHandler.ImportHtmlStatus;
import benten.twa.ui.AbstractWorkflowDialog;
import benten.twa.ui.DirectoryTextField;
import benten.ui.UiStatus;
import benten.ui.UiStatusException;

/**
 * HTML インポート・ダイアログです。
 */
public class ImportHtmlDialog extends AbstractWorkflowDialog {

	private final ImportHtmlControls controls = new ImportHtmlControls();

	public static class ImportHtmlControls {
		public DirectoryTextField fromDirText;
		public DirectoryTextField toDirText;
		public Button normalizeHtmlCheck;
	}

	public ImportHtmlDialog(Shell parentShell, IStructuredSelection selection) {
		super(parentShell, selection, "HTML のインポート");
	}

	@Override
	public void createControls(Composite composite) {
		composite.setLayout(new GridLayout(3, false));

		controls.fromDirText = new DirectoryTextField(composite, "インポート元");
		controls.fromDirText.addModifyListener(this);
		controls.fromDirText.setText(getStructuredSelectionString());

		controls.toDirText = new DirectoryTextField(composite, "インポート先");
		controls.toDirText.addModifyListener(this);

		controls.normalizeHtmlCheck = new Button(composite, SWT.CHECK);
		controls.normalizeHtmlCheck.setText("HTMLのノーマライズ（欠落している終了タグの補完）を行う");
		controls.normalizeHtmlCheck.setSelection(true);

		GridData checkGrid = new GridData();
		checkGrid.horizontalSpan = 3;
		controls.normalizeHtmlCheck.setLayoutData(checkGrid);
		copyParent(controls.fromDirText, controls.toDirText);
	}

	@Override
	public IStatus getResultStatus() {
		ImportHtmlStatus status = new ImportHtmlStatus();
		status.fromDir = controls.fromDirText.getFile();
		status.toDir = controls.toDirText.getFile();
		status.normalizeHtml = controls.normalizeHtmlCheck.getSelection();
		return status;
	}

	@Override
	public IStatus validate() throws UiStatusException {
		validatePath(controls.fromDirText);
		validatePath(controls.toDirText);
		validateFromTo(controls.fromDirText, controls.toDirText);
		return UiStatus.OK_STATUS;
	}
}
