/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.handler;

import java.io.File;
import java.io.IOException;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.dialogs.StatusDialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.xml.sax.SAXException;

import benten.core.HtmlFileFilter;
import benten.twa.filter.core.BentenConvertToXliffProcessImpl;
import benten.twa.filter.core.valueobject.BentenConvertToXliffProcessInput;
import benten.twa.filter.dialogs.ConvertToXliffDialog;
import benten.twa.ui.AbstractWorkflowDirectoryHandler;
import benten.ui.UiStatus;

/**
 * HTML－XLIFF 変換ハンドラーです。
 */
public class ConvertToXliffHandler extends AbstractWorkflowDirectoryHandler {

	public static class ConvertToXliffStatus extends UiStatus {
		public File fromDir;
		public File toDir;
	}

	@Override
	protected StatusDialog createDialog(Shell shell, IStructuredSelection selection) {
		setJobMessage("変換中...");
		return new ConvertToXliffDialog(shell, selection);
	}

	@Override
	public void run(IStatus iStatus) {
		ConvertToXliffStatus status = (ConvertToXliffStatus) iStatus;
		explore(status, status.fromDir, HtmlFileFilter.INSTANCE);
	}

	@Override
	protected void processFile(IStatus iStatus, File htmlFile) throws IOException, SAXException {
		ConvertToXliffStatus status = (ConvertToXliffStatus) iStatus;

		final BentenConvertToXliffProcessInput input = new BentenConvertToXliffProcessInput();
		input.setSourcedir(status.fromDir.getAbsolutePath());
		input.setTargetdir(status.toDir.getAbsolutePath());
		BentenConvertToXliffProcessImpl.processFile(input, htmlFile);
	}
}
