/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.handler;

import java.io.File;
import java.io.IOException;

import org.eclipse.core.commands.IHandler;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.dialogs.StatusDialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.xml.sax.SAXException;

import benten.core.HtmlFileFilter;
import benten.twa.filter.core.BentenImportHtmlProcessImpl;
import benten.twa.filter.core.valueobject.BentenImportHtmlProcessInput;
import benten.twa.filter.dialogs.ImportHtmlDialog;
import benten.twa.ui.AbstractWorkflowDirectoryHandler;
import benten.ui.UiStatus;

/**
 * HTML インポート・ハンドラーです。
 */
public class ImportHtmlHandler extends AbstractWorkflowDirectoryHandler implements IHandler {

	public static class ImportHtmlStatus extends UiStatus {
		public File fromDir;
		public File toDir;
		public boolean normalizeHtml;
	}

	@Override
	protected StatusDialog createDialog(Shell shell, IStructuredSelection selection) {
		setJobMessage("インポート中...");
		return new ImportHtmlDialog(shell, selection);
	}

	@Override
	public void run(IStatus iStatus) {
		ImportHtmlStatus status = (ImportHtmlStatus) iStatus;
		explore(status, status.fromDir, HtmlFileFilter.INSTANCE);
	}

	@Override
	protected void processFile(IStatus iStatus, File htmlFile) throws IOException, SAXException {
		ImportHtmlStatus status = (ImportHtmlStatus) iStatus;

		final BentenImportHtmlProcessInput input = new BentenImportHtmlProcessInput();
		input.setSourcedir(status.fromDir.getAbsolutePath());
		input.setTargetdir(status.toDir.getAbsolutePath());
		input.setNormalizehtml(status.normalizeHtml);
		BentenImportHtmlProcessImpl.processFile(input, htmlFile);
	}
}
