/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.model;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import benten.twa.filter.TwaFilterPlugin;

/**
 * HTML ブロックです。
 */
public class HtmlBlock {

	private static boolean IS_DEBUG = false;

	private static final Pattern enclosedTagPattern = Pattern.compile("(?i)(?s)^(<[^>]+>\\s*)(.+)(\\s*<[^>]+>)$");
	private final Matcher matcher;
	private final boolean isBlockTag;

	public HtmlBlock(String input) {
		matcher = enclosedTagPattern.matcher(input);
		isBlockTag = matcher.find();
	}

	public boolean isBlockTag() {
		return isBlockTag;
	}

	public boolean equalsStartEndTag() {
		if (startTagName().equals(endTagName())) {
			String pattern = "(?i)(?s).*<" + startTagName() + "(\\s|>).*";
			return !body().matches(pattern);
		}
		return false;
	}

	public String startTag() {
		return matcher.group(1);
	}

	public String startTagName() {
		return getTagName(startTag());
	}

	public String body() {
		return matcher.group(2);
	}

	public String endTag() {
		return matcher.group(3);
	}

	public String endTagName() {
		return getTagName(endTag());
	}

	public int endTagIndex() {
		return matcher.start(3);
	}

	private String getTagName(String tag) {
		return tag.trim().replaceAll("([/<>]|\\s\\w.+)", "");
	}

	@Override
	public String toString() {
		return startTag() + body() + endTag();
	}

	public String getInlineText() {
		if (IS_DEBUG) {
			// TODO このレベルでは Eclipse プラグインに依存しないで欲しいです。
			TwaFilterPlugin.log("");
			TwaFilterPlugin.log("[Before ] " + compressSpaces(toString()));
			TwaFilterPlugin.log("[Before1] " + compressSpaces(startTag()));
			TwaFilterPlugin.log("[Before2] " + compressSpaces(body()));
			TwaFilterPlugin.log("[Before3] " + compressSpaces(endTag()));
		}

		String text = trim(body());

		if (IS_DEBUG) {
			TwaFilterPlugin.log("---------------------------------");
			TwaFilterPlugin.log("[After  ] " + compressSpaces(text));
		}
		return text;
	}

	private String trim(String text) {

		// 前後空白除去
		String s = text.trim();

		// 前後のブロック・タグ除去
		s = HtmlBlockMatcher.trimBlockTag(s);

		// 全体が 1 つのタグ (テキスト部が無い) 、かつ翻訳が必要な属性が無い場合は空文字に
		if (s.matches("(?i)(?s)<[^<]+>") && !needsTranslationAttribute(s)) {
			return "";
		}

		// HTML コメント除去
		s = s.replaceAll("(?i)(?s)(.*?)<!--.*?-->(.*)", "$1$2");

		// 全体が属性の無い 1 つのタグ (つまりテキスト部が無い) の場合は空にする
		s = s.replaceFirst("(?i)(?s)^<[^<\\s]+>$", "");

		// タグ内のテキストが空の場合は除去
		s = HtmlBlockMatcher.trimTag(s, "<[^<]+>\\s*</[^<]+>");

		// 前後の対応するタグを除去 (属性に title や alt がある場合は除去しない)
		HtmlBlock block = new HtmlBlock(s);
		if (block.isBlockTag() && block.equalsStartEndTag()) {
			if (!needsTranslationAttribute(block.startTag())) {
				s = block.body();
			}
		}
		if (s.equals(text)) {
			return s;
		}
		return trim(s); // 再帰
	}

	private boolean needsTranslationAttribute(String text) {
		return text.matches("(?i)(?s).+?\\s(title|alt)=\".+");
	}

	private String compressSpaces(String s) {
		return s.replaceAll("[\\r\\n]+", " ").replaceAll(" {2,}", " ");
	}
}
