/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.filter.model;

import java.util.LinkedList;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * 分割された文のリストです。
 */
@SuppressWarnings("serial")
public class SentenceSplittedList extends LinkedList<String> {

	public SentenceSplittedList(String text) {
		LinkedList<String> list = split(text);
		makeWithValidate(list);
	}

	protected LinkedList<String> split(String text) {
		Matcher matcher = Pattern.compile(".+?(\\.|:)\\s+").matcher(text);
		LinkedList<String> list = new LinkedList<String>();
		while (matcher.find()) {
			StringBuffer sb = new StringBuffer();
			matcher.appendReplacement(sb, matcher.group());
			list.add(sb.toString());
		}
		StringBuffer sb = new StringBuffer();
		matcher.appendTail(sb);
		list.add(sb.toString());
		return list;
	}

	protected void makeWithValidate(LinkedList<String> list) {
		String prev = "";
		while (list.size() > 0) {
			String s = prev + list.removeFirst();
			boolean isValid = true;
			isValid = isValidSurroundPair(s, '<', '>') && isValid;
			isValid = isValidSurroundPair(s, '(', ')') && isValid;
			if (isValid) {
				add(s);
				prev = "";
			} else {
				prev = s;
			}
		}
		if (!prev.equals("")) {
			add(prev);
		}
	}

	protected boolean isValidSurroundPair(String text, char c1, char c2) {
		int c1Count = 0;
		int c2Count = 0;
		for (char c : text.toCharArray()) {
			if (c == c1) {
				c1Count++;
			} else if (c == c2) {
				c2Count++;
			}
		}
		return c1Count == c2Count;
	}
}
